summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabbercapabilitiesmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jabbercapabilitiesmanager.h')
-rw-r--r--kopete/protocols/jabber/jabbercapabilitiesmanager.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kopete/protocols/jabber/jabbercapabilitiesmanager.h b/kopete/protocols/jabber/jabbercapabilitiesmanager.h
index a783188f..f314d760 100644
--- a/kopete/protocols/jabber/jabbercapabilitiesmanager.h
+++ b/kopete/protocols/jabber/jabbercapabilitiesmanager.h
@@ -33,9 +33,10 @@ class JabberAccount;
* @author Michaƫl Larouche <michael.larouche@kdemail.net>
* @author Remko Troncon
*/
-class JabberCapabilitiesManager : public QObject
+class JabberCapabilitiesManager : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Construct
@@ -80,12 +81,12 @@ public slots:
/**
* Update if necessary the capabities for the JID passed in args.
* Caps are received in Presence messages so that's why we are
* passing a XMPP::Status object.
*
* @param jid JID that capabilities was updated.
* @param status The XMPP::Status that contain the caps.
*/
- void updateCapabilities(JabberAccount *account, const XMPP::Jid &jid, const XMPP::Status &status);
+ void updateCapabilities(JabberAccount *account, const XMPP::Jid &jid, const XMPP::tqStatus &status);
private slots:
/**
@@ -182,7 +183,7 @@ private:
void removeAccount(JabberAccount* acc);
void removeJid(const Jid&);
void addJid(const Jid&, JabberAccount*);
- QPair<Jid,JabberAccount*> nextJid(const Jid&, const Task*);
+ TQPair<Jid,JabberAccount*> nextJid(const Jid&, const Task*);
void setDiscovered(bool);
void setPendingRequests(int);
@@ -200,7 +201,7 @@ private:
int m_pendingRequests;
TQStringList m_features;
DiscoItem::Identities m_identities;
- TQValueList<QPair<TQString,JabberAccount*> > m_jids;
+ TQValueList<TQPair<TQString,JabberAccount*> > m_jids;
TQDate m_lastSeen;
};
@@ -80,12 +81,12 @@ public slots:
* Update if necessary the capabities for the JID passed in args.
* Caps are received in Presence messages so that's why we are
- * passing a XMPP::Status object.
+ * passing a XMPP::tqStatus object.
*
* @param jid JID that capabilities was updated.
@@ -80,12 +81,12 @@ public slots:
*
* @param jid JID that capabilities was updated.
- * @param status The XMPP::Status that contain the caps.
+ * @param status The XMPP::tqStatus that contain the caps.
*/